@@ -32,7 +32,7 @@ static QString guessWikipediaDomain()
 	if ( systemLanguage == QLocale::AnyLanguage || systemLanguage == QLocale::C ) {
 		languageCode = QStringLiteral("en");
 	} else {
-		languageCode = systemLocale.name().split('_').first();
+		languageCode = systemLocale.name().split(QLatin1Char('_')).first();
 	}
 
 	return QStringLiteral( "https://%1.wikipedia.org/wiki/" ).arg( languageCode );
@@ -220,8 +220,8 @@ void mapAsker::showEvent(QShowEvent *)
 			p_originalColormap = colormap;
 
 			QVector<uchar> swapableIndexes;
-			QList<const division*> divisions = p_map->getAllDivisionsOrdered();
-			foreach(const division *id, divisions)
+			const QList<const division*> divisions = p_map->getAllDivisionsOrdered();
+			for(const division *id : divisions)
 			{
 				if ( id->canAsk(division::eClick) )
 				{
